package no.ntnu.idatt1002.demo.data.recipes;

import no.ntnu.idatt1002.demo.data.Economics.*;

import java.io.*;
import java.util.Scanner;
import java.nio.file.FileSystems;
import java.time.LocalDate;

public class FileHandler {


    private static final String filePath = FileSystems.getDefault().getPath("src", "main", "resources", "recipes").toString();
    private static final String fileType = ".register";


    //private static final String filePath = "src/main/resources/recipes/";
 /*   private static final String date = "date=";
    private static final String description = "description=";
    private static final String amount = "amount=";
    private static final String isRecurring = "isRecurring=";
    private static final String category = "category=";*/


    public static void writeRegister(RecipeRegister recipeRegister) {
        if(recipeRegister == null) {
            throw new IllegalArgumentException("Only a valid register object can be written to file.");
        }

        try( FileWriter fileWriter = new FileWriter(filePath + "RecipeRegister" + fileType);) {
            recipeRegister.getRecipes().forEach((recipe) ->
                    {
                        try {
                            fileWriter.write(formatRecipe(recipe).toString());
                        } catch (IOException e) {
                            throw new RuntimeException(e);
                        }
                    }
            );

        } catch ( IOException e ) {
            e.printStackTrace();
        }
    }

    public static StringBuilder formatRecipe(Recipe recipe) {
        StringBuilder sb = new StringBuilder();
        sb.append("# ")
                .append(recipe.getName())
                .append("\n")
                .append(formatIngredientList(recipe))
                .append("\n")
                .append(recipe.getInstructions())
                .append("\n\n");

/*        story.getPassages().values().forEach((p) -> {
            sb.append(formatPassage(p))
                    .append("\n\n");
        });*/
        return sb;
    }

    public static StringBuilder formatIngredientList(Recipe recipe) {
        StringBuilder sb = new StringBuilder();

        recipe.getIngredientList().forEach((ingredient) -> {
            sb.append("- ")
                    .append(ingredient.getFoodType())
                    .append(" | ")
                    .append(ingredient.getAmount())
                    .append(" | ")
                    .append(ingredient.getUnit());
        });

        return sb;
    }



    //TODO: Midlertidig for testing.
    public static void readToTerminal(String title) throws FileNotFoundException {
        File file = new File(filePath + title.replace(" ","_") + fileType);
        Scanner sc = new Scanner(file);
        while(sc.hasNext()) {
            System.out.println(sc.nextLine());
        }
    }

/*


    public <T extends Item>void writeItemRegisterToFile(final ItemRegister<T> itemRegister, String fileTitle) throws IOException {
        try (BufferedWriter bw = new BufferedWriter(new FileWriter(filePath + fileTitle + fileType))) {
            if (itemRegister.isEmpty()){
                bw.write("");
            } else{
                bw.write(itemRegister.toString());
            }
        } catch (IOException ex) {
            throw new IOException("Error writing story to file: " + ex.getMessage());
        }
    }

    */
/**
     * Method for checking if a .register file is empty.
     *
     * @param fileTitle the name of the file you want to check
     * @return true or false depending on if file is empty.
     * @throws IOException if an input or output exception occurred.
     *//*

    public boolean isEmpty(String fileTitle) throws IOException {
        try (BufferedReader br = new BufferedReader(new FileReader(filePath + fileTitle + fileType))) {
            if (br.readLine() == null) {
                return true;
            } else {
                return false;
            }
        }
    }

    */
/**
     * Method for reading (getting) an IncomeRegister from a file.
     *
     * @param fileTitle the name of the file you want to read from.
     * @return the IncomeRegister from the file.
     * @throws IOException if an input or output exception occurred.
     *//*

    public IncomeRegister readIncomeRegisterFromFile(String fileTitle) throws IOException {
        IncomeRegister incomeRegister = new IncomeRegister();
        LocalDate date = null;
        String description = "";
        double amount = 0;
        boolean reoccuring = false;
        IncomeCategory incomeCategory = null;
        try (BufferedReader br = new BufferedReader(new FileReader(filePath + fileTitle + fileType))) {
            String line;
            String nextLine = br.readLine();
            while ((line = nextLine) != null) {
                nextLine = br.readLine();
                if(line.startsWith(FileHandling.date)) {
                    date = LocalDate.parse(line.replace(FileHandling.date, ""));
                } else if (line.startsWith(FileHandling.description)) {
                    description = line.replace(FileHandling.description,"");
                } else if (line.startsWith(FileHandling.amount)) {
                    amount = Double.parseDouble(line.replace(FileHandling.amount,""));
                } else if (line.startsWith(FileHandling.isRecurring)) {
                    reoccuring = line.replace(FileHandling.isRecurring,"").equals("Recurring");
                } else if (line.startsWith(FileHandling.category)) {
                    line = line.replace(FileHandling.category,"");
                    incomeCategory = switch (line) {
                        case "GIFT" -> IncomeCategory.GIFT;
                        case "STUDENT_LOAN" -> IncomeCategory.STUDENT_LOAN;
                        default -> IncomeCategory.SALARY;
                    };
                } if(line.isEmpty() || (nextLine == null)) {
                    if(description.equals("")){
                        incomeRegister.addItem(new Income(amount, reoccuring, incomeCategory, date));
                    } else{
                        incomeRegister.addItem(new Income(description, amount, reoccuring, incomeCategory, date));
                    }
                    description = "";
                }
            }
        }
        return incomeRegister;
    }

    */
/**
     * Method for reading (getting) an ExpenseRegister from a file.
     *
     * @param fileTitle the name of the file you want to read from.
     * @return the ExpenseRegister from the file.
     * @throws IOException if an input or output exception occurred
     *//*

    public ExpenseRegister readExpenseRegisterFromFile(String fileTitle) throws IOException {
        ExpenseRegister expenseRegister = new ExpenseRegister();
        LocalDate date = null;
        String description = "";
        double amount = 0;
        boolean reoccuring = false;
        ExpenseCategory expenseCategory = null;
        try (BufferedReader br = new BufferedReader(new FileReader(filePath + fileTitle + fileType))) {
            String line;
            String nextLine = br.readLine();
            while ((line = nextLine) != null) {
                nextLine = br.readLine();
                if (line.startsWith(FileHandling.date)) {
                    date = LocalDate.parse(line.replace(FileHandling.date, ""));
                } else if (line.startsWith(FileHandling.description)) {
                    description = line.replace(FileHandling.description, "");
                } else if (line.startsWith(FileHandling.amount)) {
                    amount = Double.parseDouble(line.replace(FileHandling.amount, ""));
                } else if (line.startsWith(FileHandling.isRecurring)) {
                    reoccuring = line.replace(FileHandling.isRecurring, "").equals("Recurring");
                } else if (line.startsWith(FileHandling.category)) {
                    line = line.replace(FileHandling.category, "");
                    expenseCategory = switch (line) {
                        case "FOOD" -> ExpenseCategory.FOOD;
                        case "CLOTHES" -> ExpenseCategory.CLOTHES;
                        case "BOOKS" -> ExpenseCategory.BOOKS;
                        default -> ExpenseCategory.OTHER;
                    };
                }
                if (line.isEmpty() || (nextLine == null)) {
                    if (description.equals("")) {
                        expenseRegister.addItem(new Expense(amount, reoccuring, expenseCategory, date));
                    } else {
                        expenseRegister.addItem(new Expense(description, amount, reoccuring, expenseCategory, date));
                    }
                    description = "";
                }
            }
        }
        return expenseRegister;
    }
}
*/



}
